import pandas as pd
def to_git_markdown(df, max_col_width=30, max_rows=-1):
    """
    Convert a pandas DataFrame to a GitHub-flavored markdown table string.

    Parameters:
    df (pd.DataFrame): The DataFrame to convert.
    max_col_width (int): Maximum width for each column in the markdown table. Default is 30.
    max_rows (int): Maximum number of rows to include in the table. If -1, include all rows.

    Returns:
    str: A string representing the DataFrame in GitHub-flavored markdown table format.
    """
    if max_rows <= 0:
        max_rows = len(df)
    df2 = df.iloc[:max_rows].copy()
    df2.insert(0, "index", df2.index)
    for col in df2.columns:
        df2[col] = (
            df2[col]
            .astype(str)
            .str.strip()
            .str.replace("\r\n", "\\r\\n")
            .str.replace("\n", "\\n")
            .str.replace("|", " ")
            .apply(lambda x: x[:max_col_width].ljust(max_col_width) + " | ")
        )

    cols = (
        "| "
        + " | ".join(
            (str(col)[:max_col_width].ljust(max_col_width) for col in df2.columns)
        )
        + " | "
    )
    secondlinelist = []
    for col in cols:
        if col != "|":
            secondlinelist.append("-")
        else:
            secondlinelist.append("|")
    secondline = "".join(secondlinelist).replace("-|-", " | ").replace("|-", "| ").replace("-|", " |")
    dfrowsstring = []
    for key, item in df2.iterrows():
        dfrowsstring.append("| " + "".join(item.to_list()))
    return cols + "\n" + secondline + "\n" + "\n".join(dfrowsstring)